@@ -4,7 +4,7 @@ from urllib.parse import urlparse
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.db import models
+from django.db import models, transaction
 from django.utils import timezone
 
 from djangorestframework_camel_case.util import camelize
@@ -155,13 +155,17 @@ class NotificationMixin(metaclass=NotificationMixinBase):
             client.create("notificaties", message)
         # any unexpected errors should show up in error-monitoring, so we only
         # catch ClientError exceptions
-        except ClientError as exc:
+        except ClientError:
             logger.warning(
-                "Could not deliver message to %s", client.base_url, exc_info=True
+                "Could not deliver message to %s",
+                client.base_url,
+                exc_info=True,
+                extra={"notification_msg": message, "status_code": status_code,},
             )
 
 
 class NotificationCreateMixin(NotificationMixin):
+    @transaction.atomic
     def create(self, request, *args, **kwargs):
         response = super().create(request, *args, **kwargs)
         self.notify(response.status_code, response.data)
@@ -169,6 +173,7 @@ class NotificationCreateMixin(NotificationMixin):
 
 
 class NotificationUpdateMixin(NotificationMixin):
+    @transaction.atomic
     def update(self, request, *args, **kwargs):
         response = super().update(request, *args, **kwargs)
         self.notify(response.status_code, response.data)
@@ -176,6 +181,7 @@ class NotificationUpdateMixin(NotificationMixin):
 
 
 class NotificationDestroyMixin(NotificationMixin):
+    @transaction.atomic
     def destroy(self, request, *args, **kwargs):
         # get data via serializer
         instance = self.get_object()
